@@ -4,9 +4,14 @@ import time,os,math,inspect,re,errno
 import random,glob,math
 from shutil import copyfile
 import sensenet
+from sensenet import spaces
 from sensenet.error import Error
 
 class HandEnv(sensenet.SenseEnv):
+    metadata = {
+        'render.modes': ['rgb_array'],
+        'video.frames_per_second' : 30
+    }
     def getKeyboardEvents(self):
         return pb.getKeyboardEvents()
 
@@ -26,7 +31,6 @@ class HandEnv(sensenet.SenseEnv):
         currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
         parentdir = os.path.dirname(os.path.dirname(currentdir))
         os.sys.path.insert(0,parentdir)
-        #TODO check if options is a string, so we know which environment to load
         if 'render' in self.options and self.options['render'] == True:
             pb.connect(pb.GUI)
         else:
@@ -55,28 +59,35 @@ class HandEnv(sensenet.SenseEnv):
         self.offset = 0.02 # Offset from basic position
         self.downCameraOn = False
         self.prev_distance = 10000000
+        self.action_space = spaces.Discrete(8)
+        self.touch_width = 200
+        self.touch_height = 200
+        self.observation_space = spaces.Box(0, 1, [self.touch_width, self.touch_height])
     def load_object(self):
         #we assume that the directory structure is: SOMEPATH/classname/SHA_NAME/file
-        #TODO refactor this whole mess later
+        #TODO refactor this whole mess later after addings tons of unit testing!!!!
         obj_x = 0
         obj_y = -1
         obj_z = 0
         if 'random_orientation' in self.options:
             orientation = (random.random(),random.random(),random.random(),random.random())
         else:
-            orientation = (0,0,0,0)
+            orientation = (0,0,1,0)
 
         if 'obj_type' in self.options:
             obj_type = self.options['obj_type']
         elif 'obj_path' in self.options and self.options['obj_path'] != None and 'obj' in self.options['obj_path']:
             obj_type = 'obj'
-        else: #TODO change default to obj after more performance testing
+        elif 'obj_path' in self.options and self.options['obj_path'] != None and 'stl' in self.options['obj_path']:
             obj_type = 'stl'
+        else: #TODO change default to obj after more performance testing
+            obj_type = 'obj'
         if 'obj_path' not in self.options or ('obj_path' in self.options and self.options['obj_path'] == None):
             path = self.get_data_path()
             if path == None:
                 dir_path = os.path.dirname(os.path.realpath(__file__))
                 stlfile = dir_path + "/data/pyramid.stl"
+                stlfile = dir_path + "/data/missile.obj"
             else:
                 files = glob.glob(path+"/**/*."+obj_type,recursive=True)
                 try:
@@ -86,9 +97,9 @@ class HandEnv(sensenet.SenseEnv):
                                     % (obj_type, path))
                 #TODO copy this file to some tmp area where we can guarantee writing
                 if os.name == 'nt':
-                    self.class_label = int(stlfile.split("\\")[-3].split("_")[0])
+                    self.class_label = int(stlfile.split("\\")[-2].split("_")[0])
                 elif os.name == 'posix' or os.name == 'mac':
-                    self.class_label = int(stlfile.split("/")[-3].split("_")[0])
+                    self.class_label = int(stlfile.split("/")[-2].split("_")[0])
                 #class labels are folder names,must be integer or N_text
                 #print("class_label: ",self.class_label)
         else:
@@ -103,7 +114,7 @@ class HandEnv(sensenet.SenseEnv):
         if self.get_data_path() == None:
             return None
         else:
-            path = os.path.join(self.get_data_path(), "objects/*/")
+            path = os.path.join(self.get_data_path(), "*/")
             subd = glob.glob(path)
             return len(subd)
 
@@ -145,6 +156,35 @@ class HandEnv(sensenet.SenseEnv):
     def action_space_n(self):
         return len(self.action_space())
 
+    def _render(self, mode="rgb_array", close=False):
+        if mode != "rgb_array":
+            return np.array([])
+        base_pos = [0,0,0]
+        _cam_dist = 5  #.3
+        _cam_yaw = 50
+        _cam_pitch = -35
+        _render_width=480
+        _render_height=480
+
+        view_matrix = pb.computeViewMatrixFromYawPitchRoll(
+            cameraTargetPosition=base_pos,
+            distance=_cam_dist,
+            yaw=_cam_yaw,
+            pitch=_cam_pitch,
+            roll=0,
+            upAxisIndex=2)
+        proj_matrix = pb.computeProjectionMatrixFOV(
+            fov=90, aspect=float(_render_width)/_render_height,
+            nearVal=0.01, farVal=100.0)
+        #proj_matrix=[1.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, -1.0000200271606445, -1.0, 0.0, 0.0, -0.02000020071864128, 0.0]
+        (_, _, px, _, _) = pb.getCameraImage(
+            width=_render_width, height=_render_height, viewMatrix=view_matrix,
+            projectionMatrix=proj_matrix, renderer=pb.ER_BULLET_HARDWARE_OPENGL)
+            #projectionMatrix=proj_matrix, renderer=pb.ER_TINY_RENDERER) #ER_BULLET_HARDWARE_OPENGL)
+        rgb_array = np.array(px, dtype=np.uint8)
+        rgb_array = np.reshape(rgb_array, (_render_height, _render_width, 4))
+        rgb_array = rgb_array[:, :, :3]
+        return rgb_array
 
     def ahead_view(self):
         link_state = pb.getLinkState(self.agent,self.indexEndID)
@@ -188,8 +228,6 @@ class HandEnv(sensenet.SenseEnv):
 
         return viewMatrix
 
-
-            #return random.random()
     def _step(self,action):
         done = False
         #reward (float): amount of reward achieved by the previous action. The scale varies between environments, but the goal is always to increase your total reward.
@@ -221,8 +259,6 @@ class HandEnv(sensenet.SenseEnv):
         roll=0
         upAxisIndex = 2
         camDistance = 4
-        pixelWidth = 320
-        pixelHeight = 240
         nearPlane = 0.0001
         farPlane = 0.022
         lightDirection = [0,1,0]
@@ -326,7 +362,7 @@ class HandEnv(sensenet.SenseEnv):
         if self.downCameraOn: viewMatrix = down_view()
         else: viewMatrix = self.ahead_view()
         projectionMatrix = pb.computeProjectionMatrixFOV(fov,aspect,nearPlane,farPlane)
-        w,h,img_arr,depths,mask = pb.getCameraImage(200,200, viewMatrix,projectionMatrix, lightDirection,lightColor,renderer=pb.ER_TINY_RENDERER)
+        w,h,img_arr,depths,mask = pb.getCameraImage(self.touch_width,self.touch_height, viewMatrix,projectionMatrix, lightDirection,lightColor,renderer=pb.ER_TINY_RENDERER)
         #w,h,img_arr,depths,mask = pb.getCameraImage(200,200, viewMatrix,projectionMatrix, lightDirection,lightColor,renderer=pb.ER_BULLET_HARDWARE_OPENGL)
         new_obs = np.absolute(depths-1.0)
         new_obs[new_obs > 0] =1
@@ -378,7 +414,7 @@ class HandEnv(sensenet.SenseEnv):
         self.load_object()
         self.load_agent()
         #return observation
-        default = np.zeros((40000))
+        default = np.zeros((self.touch_width * self.touch_height))
         self.steps = 0
         self.current_observation = default
         return default
